import json
import urllib.parse
import sys
import os
from datetime import datetime
from opensearchpy import helpers, OpenSearch
USERNAME = "admin"
PASSWD = "admin"


#### TO-DO Adapting to push data upon OpenSearch
### Each repo json object should have a key called date with timestamp at pushing time

GITHUB_ORGS_INDEX = { 'index_name': 'otterdog-github-orgs', 
                     'index_keys_list': ['github_id', 'secrets', 'settings', 'webhooks'],
                     'index_id_key': 'github_id'}

GITHUB_REPOSITORIES_INDEX = { 'index_name': 'otterdog-github-repositories', 
                     'index_keys_list': 'repositories',
                     'index_id_key': ['github_id', 'name']}

OS_HOSTNAME="opensearch-node1"


# Replace these with your actual MongoDB connection details
db_name = "otterdogdb"
collection_name = "organizations"
data_path="/output"



### TO-DO refactor thi funciton to load data based which needs to be unwinded
def load_data(json_file_path, opensearch_index):
    # Load JSON data from file
    print(f"Processing file {json_file_path}")
    # Adding timestamp
    data = []
    with open(json_file_path, "r") as json_file:
        timestamp = datetime.now()
        json_data = json.load(json_file)

        if isinstance(opensearch_index['index_keys_list'], list):
            index_data = { k:json_data[k] for k in opensearch_index['index_keys_list']}
            data.append(index_data)
        elif isinstance(opensearch_index['index_keys_list'], str):
            data = json_data[opensearch_index['index_keys_list']]
        else:
            raise Exception(f"ERROR!!! processing {opensearch_index['index_name']}. An expected value for opensearch_index['index_keys_list']: {opensearch_index['index_keys_list']}. Expected a list or string")
        
        for d in data:
            if isinstance(opensearch_index['index_id_key'], str):
                _id_index = json_data[opensearch_index["index_id_key"]]
            elif isinstance(opensearch_index['index_id_key'], list):
                ### TO-DO refector the code to allow something more general than a fixed list: ['github_id', 'name']
                index_id_key_lst = opensearch_index["index_id_key"]
                _id_index = '_'.join([json_data[index_id_key_lst[0]],d[index_id_key_lst[1]]])
                ## Adding github_id
                d['github_id'] = json_data[ 'github_id' ]
            else:
                raise Exception(f"ERROR!!! processing {opensearch_index['index_name']}. An expected value for opensearch_index[index_id_key]: {opensearch_index['index_id_key']}. Expected a list or string")
            
            d['@timestamp'] = timestamp.strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3]
            d['sort']=int(timestamp.timestamp()*1000)
            yield {'_index': f'{opensearch_index["index_name"]}', '_id':f'{_id_index}', "_type":"doc", '_source': d}

def insert_json_file(json_file_path):
    # Escape the username and password using quote_plus
    username = urllib.parse.quote_plus(USERNAME)
    password = urllib.parse.quote_plus(PASSWD)

    SERVICE_URI = f"https://{username}:{password}@{OS_HOSTNAME}:9200"
 
    # Connect to OpenSearch
    os_client = OpenSearch(hosts=SERVICE_URI, ssl_enable=True,verify_certs=False)

    if os_client:
        print(f"Connected to server: {OS_HOSTNAME}")
        try:
            ### Loading Github orgs data
            helpers.bulk(os_client, load_data(json_file_path, GITHUB_ORGS_INDEX))

            ### Loading repositroes data
            helpers.bulk(os_client, load_data(json_file_path, GITHUB_REPOSITORIES_INDEX))
        except Exception as ex:
            print(f"ERROR!!!, connecting to {SERVICE_URI} msg {ex}")

def check_parameters():
    # Check if a JSON file path is provided as a command-line argument
    if len(sys.argv) != 2:
        print("Usage: python load.py path/to/your/json/file.json")
        sys.exit(1)
    else:
        return sys.argv[1]



def main():
    for filename in os.listdir(data_path):
        if filename.endswith(".json"):
            file_path = os.path.join(data_path,filename)
            insert_json_file(file_path)
            print(f"Processed file: {filename}")

    
    


if __name__ == "__main__":
    main()